@@ -565,9 +565,11 @@ class ldmStorage(ldmUtilLog):
             sType   ... type enforcement
             oDft    ... default value
         ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+            return code
+                >0  ... okay processing done
+                =0  ... okay nop
+                <0  ... error
+            value
         """
         try:
             # +++++ beg:initialize
