@@ -217,7 +217,7 @@ class ldmStorageFolder(ldmStorage):
         except:
             self.logTB()
             return -1
-    def prcExc(self,**kwargs):
+    def prcExc(self,oNty=None,**kwargs):
         """processing execution
         ### parameter
             **kwargs ... flexible keyword argument
@@ -254,12 +254,13 @@ class ldmStorageFolder(ldmStorage):
             # ----- end:get configuration
             # +++++ beg:walk through directory recursive
             for sRoot,lDN,lFN in os.walk(sDef):
-                #sCurDN='./'+sRoot[iSrcLen:].replace(os.sep,'/')
                 if self.iVerbose>90:
                     self.logDbg('        sRoot:%s',sRoot)
                 sCurDN,dDN,dFN=self.getDatContent(sRoot)
-                #if self.iVerbose>0:
-                #    self.logDbg('        sCurDN:%s',sCurDN)
+                if oNty is not None:
+                    oNty.SetStatus(sCurDN)
+                if self.iVerbose>0:
+                    self.logDbg('        sCurDN:%s',sCurDN)
                 #dFiles={}
                 #dContent={'.':dFiles}
                 #self.lFdr.append(sCurDN)
