@@ -61,6 +61,21 @@ class ldmWidApp(wx.App):
                     filename=filename,
                     useBestVisual=useBestVisual,
                     clearSigInt=clearSigInt)
+    def getCfgFN(self,oArg=None):
+        """get configuration file name
+        ### parameter
+            oArg    ... object assumed to hold arguments
+        ### return
+            filename .. okay
+            None    ... error
+        """
+        try:
+            if oArg is not None:
+                sCfgFN=oArg.sCfgFN
+                return sCfgFN
+        except:
+            pass
+        return None
     def OnInit(self):
         """
         ### parameter
@@ -69,22 +84,29 @@ class ldmWidApp(wx.App):
             False ... okay nop
         """
         # +++++ beg:
+        sCfgFN=self.getCfgFN(oArg=self.oArg)
         # ----- end:
+        # +++++ beg:
         if self.clsFrm is None:
             self.frmAui = ldmWidFrmAui(iLv=0,
                         sLogger='frmAui',
                         title=self.sTitle,
                         oArg=self.oArg,
+                        sCfgFN=sCfgFN,
                         ldmCfg=None)
         else:
             self.frmAui = self.clsFrm(iLv=0,
                         sLogger='frmAui',
                         title=self.sTitle,
                         oArg=self.oArg,
+                        sCfgFN=sCfgFN,
                         ldmCfg=None,
                         **self.kwargs)
+        # ----- end:
+        # +++++ beg:
         self.SetTopWindow(self.frmAui.GetWid())
         self.frmAui.GetWid().Show()
+        # ----- end:
         return True
 
 # end of class ldmWidApp
