@@ -13,6 +13,7 @@
 import types
 import six
 import json
+import os
 
 import wx
 
@@ -45,7 +46,7 @@ def ldmWidCoreGetIcon(bmp):
     return icon
 
 class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
-    def __init__(self,sLogger='',iLv=1,iVerbose=0,**kwargs):
+    def __init__(self,sLogger='',iLv=1,iVerbose=0,sCfgFN=None,**kwargs):
         """constructor
         several sub constructor methods are called
         
@@ -67,10 +68,16 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
                 4       ... critical
                 x       ... debug
             iVerbose    ... higher values add more logs
+            sCfgFN  ... json configuration file
             kwargs  ... keyword arguments passed to all init methods
         """
         ldmUtilLog.__init__(self,sLogger,iLv=iLv,
                     iVerbose=iVerbose)
+        try:
+            if sCfgFN is not None:
+                self.loadCfgWid(sCfgFN=sCfgFN)
+        except:
+            self.logTB()
         try:
             self.__initCls__(**kwargs)
             self.__initCfg__(**kwargs)
@@ -102,7 +109,12 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logDbg('beg:%s'%(sOrg))
             # ----- end:initialize
             # +++++ beg:
-            self.dCfgWid=None
+            if hasattr(self,'dCfgWid'):
+                pass
+            else:
+                self.dCfgWid=None
+            # ----- end:
+            # +++++ beg:
             self.dCfgWidDft={
                 'common':{
                     'bmpWidth':32,
@@ -594,7 +606,7 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         """
         try:
             # +++++ beg:initialize
-            sOrg='ldmStorage::loadCfg'
+            sOrg='ldmWidCore::loadCfgWid'
             self.oLog.debug('beg:%s iVerbose:%d'%(sOrg,self.iVerbose))
             iRet=0
             # ----- end:initialize
@@ -606,6 +618,10 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
                     self.dCfgWid=json.loads(oFile.read())
                 iRet=1
             # ----- end:read cfg file
+            # +++++ beg:verbose cfg dict
+            if self.iVerbose>=30:
+                self.oLog.debug('%r %r',self.sCfgWidFN,self.dCfgWid)
+            # ----- end:verbose cfg dict
             # +++++ beg:finalize
             self.oLog.debug('end:%s  iRet:%d'%(sOrg,iRet))
             # ----- end:finalize
